==> apache-superset-incubating-0.36.0-source.tar.gz: apache-superset-incubating-0.36.0rc3/superset-frontend/spec/javascripts/CRUD/CollectionTable_spec.jsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { shallow } from 'enzyme';

import CollectionTable from '../../../src/CRUD/CollectionTable';
import mockDatasource from '../../fixtures/mockDatasource';

const props = {
  collection: mockDatasource['7__table'].columns,
  tableColumns: ['column_name', 'type', 'groupby'],
};

describe('CollectionTable', () => {
  let wrapper;
  let el;

  beforeEach(() => {
    el = <CollectionTable {...props} />;
    wrapper = shallow(el);
  });

  it('is valid', () => {
    expect(React.isValidElement(el)).toBe(true);
  });

  it('renders a table', () => {
    const length = mockDatasource['7__table'].columns.length;
    expect(wrapper.find('table')).toHaveLength(1);
    expect(wrapper.find('tbody tr.row')).toHaveLength(length);
  });
});

==> apache-superset-incubating-0.37.0-source.tar.gz: apache-superset-incubating-0.37.0rc4/superset-frontend/spec/javascripts/CRUD/CollectionTable_spec.jsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { shallow } from 'enzyme';

import CollectionTable from 'src/CRUD/CollectionTable';
import mockDatasource from '../../fixtures/mockDatasource';

const props = {
  collection: mockDatasource['7__table'].columns,
  tableColumns: ['column_name', 'type', 'groupby'],
};

describe('CollectionTable', () => {
  let wrapper;
  let el;

  beforeEach(() => {
    el = <CollectionTable {...props} />;
    wrapper = shallow(el);
  });

  it('is valid', () => {
    expect(React.isValidElement(el)).toBe(true);
  });

  it('renders a table', () => {
    const length = mockDatasource['7__table'].columns.length;
    expect(wrapper.find('table')).toHaveLength(1);
    expect(wrapper.find('tbody tr.row')).toHaveLength(length);
  });
});
